@@ -1,6 +1,6 @@
 #!/usr/local/bin/perl
 # install-module.pl
-# Install a single module file
+# Install a single Usermin module file
 
 # Check arguments
 $nodeps = 0;
@@ -8,12 +8,8 @@ if ($ARGV[0] eq "--nodeps") {
 	shift(@ARGV);
 	$nodeps = 1;
 	}
-while($ARGV[0] eq "--acl") {
-	shift(@ARGV);
-	push(@grant, shift(@ARGV));
-	}
 if (@ARGV > 2 || !@ARGV) {
-	die "usage: install-module.pl [--nodeps] [--acl user]* <module.wbm> [config_directory]";
+	die "usage: install-module.pl [--nodeps] <module.wbm> [config_directory]";
 	}
 $file = $ARGV[0];
 $config = $ARGV[1] ? $ARGV[1] : "/etc/webmin";
@@ -45,15 +41,8 @@ do './web-lib.pl';
 &init_config();
 
 # Install it, using the standard function
-&foreign_require("webmin", "webmin-lib.pl");
-if (@grant) {
-	$newusers = \@grant;
-	}
-else {
-	$newusers = &webmin::get_newmodule_users();
-	$newusers ||= [ "root", "admin" ];
-	}
-$rv = &webmin::install_webmin_module($file, 0, $nodeps, $newusers);
+&foreign_require("usermin", "usermin-lib.pl");
+$rv = &usermin::install_usermin_module($file, 0, $nodeps);
 if (ref($rv)) {
 	for($i=0; $i<@{$rv->[0]}; $i++) {
 		printf "Installed %s in %s (%d kb)\n",
